// Create and delete dynamically allocated, contiguous 2D array
// The array is accessed as [j][i] with i the fastest-varying (contiguous) index.
template<typename T> T** create2DArray(int jmax, int imax){ 
  T  **m_buffer = new T*[jmax];
  T   *m_tempxy = new T[jmax*imax];
  for ( int j = 0 ; j < jmax ; j++, m_tempxy += imax ) {
    m_buffer[j] = m_tempxy;
  }
  return m_buffer;
}


template<typename T> void delete2DArray(T** c){
  delete[] c[0];
  delete[] c; 
}


// Create and delete dynamically allocated, contiguous 3D array.
// The array is accessed as [k][j][i] with i the fastest-varying (contiguous) index.
template<typename T> T*** create3DArray(int kmax, int jmax, int imax){ 
  T ***m_buffer = new T**[kmax];
  T  **m_tempxy = new T*[kmax*jmax];
  T   *m_tempxyz = new T[kmax*jmax*imax];
  for ( int k = 0 ; k < kmax ; k++, m_tempxy += jmax ) {
    m_buffer[k] = m_tempxy;
    for ( int j = 0 ; j < jmax ; j++, m_tempxyz += imax ) {
      m_buffer[k][j] = m_tempxyz;
    }
  }
  return m_buffer;
}


template<typename T> void delete3DArray(T*** c){
  delete[] c[0][0];
  delete[] c[0];
  delete[] c; 
}


// Create and delete dynamically allocated, contiguous 4D array.
// The array is accessed as [l][k][j][i] with i the fastest-varying (contiguous) index.
template<typename T> T**** create4DArray(int lmax, int kmax, int jmax, int imax){ 
  T ****m_buffer2 = new T***[lmax];
  T ***m_buffer   = new T**[lmax*kmax];
  T  **m_tempxy   = new T*[lmax*kmax*jmax];
  T   *m_tempxyz  = new T[lmax*kmax*jmax*imax];
  for ( int l = 0 ; l < lmax ; l++, m_buffer += kmax ) {
    m_buffer2[l] = m_buffer;
    for ( int k = 0 ; k < kmax ; k++, m_tempxy += jmax ) {
      m_buffer2[l][k] = m_tempxy;
      for ( int j = 0 ; j < jmax ; j++, m_tempxyz += imax ) {
        m_buffer2[l][k][j] = m_tempxyz;
      }
    }
  }
  return m_buffer2;
}


template<typename T> void delete4DArray(T**** c){
  delete[] c[0][0][0];
  delete[] c[0][0];
  delete[] c[0];
  delete[] c; 
}
