/*!  \file constants.h
 *   \brief This is a repository for global constants.
 *
 *   These set/define the sizes of arrays, etc. This file must be
 *   "#included" in any ".cpp" which in turn "#includes" any other 
 *   ".h" files which uses arrays making use of the values below.
 *
 *   \param smallvalue (const double) specifes what stands for a small value in the code
 *   \param debug_lev (const int) sets the debug level for non-MPI code
 *            ( 0 = no messages, 1 = some messages, 3 = more messages, 5 = ALL messages)
 *   \param debug_mpi (const bool) sets the debug option for MPI code 
 *            (false = no messages, true = debug messages)
 *
 *   \author Julian Pittard (Original version 31.05.11)
 *   \version 0.1-development (Undómiel):
 *   \date Last modified: 31.05.11 (JMP)
 */

  //////////////////////////////////////////////////////////////////////
  //                                                                  //
  //                   SET UP CODE PARAMETERS                         //
  //     ...students can (carefully) alter these values...            //
  //                                                                  //
  //       NOTE: Remember to recompile after making changes!          // 
  //                                                                  //
  //////////////////////////////////////////////////////////////////////


  //////////////////////////////////////////////////////////////////////
  //                                                                  //
  //    STUDENTS SHOULD NOT CHANGE THE CODE BELOW THIS POSITION       //
  //                                                                  //
  //////////////////////////////////////////////////////////////////////


const double smallvalue = 1.0e-40;  // small value in code

const int debug_lev = 0;      // Set debug level for non-MPI code
                              // 0 = no messages
                              // 1 = some messages
                              // 3 = more messages
                              // 5 = ALL messages
const bool debug_mpi = false;  // false = no messages, true = debug messages

const double avisp = 0.0; // artificial viscosity    (default 0.2)
const double avise = 0.0; // artificial conductivity (default 0.2)   

                                                                     
// Enum for integer constants to identify MPI messages sent in various parts of code (see Athena defs.h)
// Starts at 0.
enum {dataLtoR_tag, ///< Sending data from Left to Right
      dataRtoL_tag  ///< Sending data from Right to Left
};
