/*!  \file global.h
 *   \brief  This is a repository for global variables and constants.
 *
 *   \param problem (string) defines the problem being tackled
 *   \param ncycle (int) specifies the current cycle number
 *   \param t1 (double) specifes the start time of the current march
 *   \param t2 (double) specifes the end time of the current march
 *   \param t (double) specifes the current time (s) of the calculation
 *   \param dt (double) specifes the current timestep (s) of the calculation
 *   \param svel (double) specifes the sound speed
 *   \param ramb (double) is the ambient density (g/cm^-3)
 *   \param pamb (double) is the ambient pressure (dyn/cm^-2)
 *   \param tamb (double) is the ambient temperature (K)
 *   \param uamb (double) is the ambient velocity (cm/s)
 *   \param camb (double) is the ambient sound speed (cm/s)
 *   \param avgmassamb (double) is the ambient average mass (g)
 *   \param muamb (double) is the ambient average mass (in units of mH)
 *   \param tmin (double) is the temperature floor (K)
 *   \param tmax (double) is the maximum permitted (K)
 *   \param dotflo (double) is a fixed density outflow at the grid boundary
 *
 *   \author Julian Pittard (Original version 31.05.11)
 *   \version 0.1-development (Undómiel):
 *   \date Last modified: 13.09.11 (JMP)
 */

#include <iostream>
#include <string>

using namespace std;

// Variables
#ifdef MAIN
  bool mpi = false;           // set true if grid is tiled (i.e. size > 1)
  bool debugMPI = false;      // debug output for the MPI code?
  bool reStart = false;       // reStart the current problem?
  string problem;             // the problem being tackled
  string prefx = "cwb";       // prefix to dump files
  string datadir;             // the directory to dump/read data to/from
  int procRank = 0;           // processor rank
  int size = 1;               // number of MPI processes
  int ipro = 0;               // i-rank of MPI process (starts at 0)
  int jpro = 0;               // j-rank of MPI process (starts at 0)
  int kpro = 0;               // k-rank of MPI process (starts at 0)
  int liProID = 0;            ///< id of processor to left in direction i (default to 0 helps with periodic boundaries on a single processor calc)
  int riProID = 0;            ///< id of processor to right in direction i
  int ljProID = 0;            ///< id of processor to left in direction j
  int rjProID = 0;            ///< id of processor to right in direction j
  int lkProID = 0;            ///< id of processor to left in direction k
  int rkProID = 0;            ///< id of processor to right in direction k
  int ncycle;                 // the current number of hydro steps taken
  int nprin1d = 1e9;          // cycles between output of 1D dump files 
  int nprin2d = 1e9;          // cycles between output of 2D dump files
  int nprin3d = 1e9;          // cycles between output of 3D dump files
  int ncycp1d,ncycp2d,ncycp3d;// elapsed steps since last 1D/2D/3D output
  int ncycshow = 100;          // number of steps before outputing cycle
  int ncycend = 1e9;          // number of steps before ending code
  int nfile1d;                // file index for 1d dumps
  int nfile2d;                // file index for 2d dumps
  int nfile3d;                // file index for 3d dumps
  int sc,ec;                  // start and end cycles when timing
  int remapi;                 // number of cells in remap radius
  double tprin1d = 1.0e99;    // time between 1D dumps
  double tprin2d = 1.0e99;    // time between 2D dumps
  double tprin3d = 1.0e99;    // time between 3D dumps
  double timep1d,timep2d,timep3d; // elapsed time since last 1D/2D/3D output
  double endtime = 1.0e99;    // endtime
  double t;                   // current time
  double dt;                  // current timestep
  double svel;                // sound speed
#ifdef UNSPLIT
#if NDIM == 1
  double cn = 0.4;            //courant number (PLMDE 1D)
#elseif NDIM == 2
  double cn = 0.25;           //courant number (PLMDE 2D)
#else
  double cn = 0.2;            //courant number (PLMDE 3D)
#endif
#else
  double cn = 0.6;            //courant number (PPMLR)
#endif
  double ramb,pamb,tamb,uamb,vamb,wamb,camb,avgmassamb,muamb,tmin,tmax;
double dustToGasMassRatio,clumpToInterClumpMassRatio,q0,fML,grainRadius,grainBulkDensity;
  double remapRadius;
  double mdot,vinf,esn,msn;
  double GammaHeat;
#else
extern bool mpi,debugMPI,reStart;
extern string problem,prefx,datadir;
extern int procRank,size,ipro,jpro,kpro,liProID,riProID,ljProID,rjProID,lkProID,rkProID;
extern int ncycle,nprin1d,nprin2d,nprin3d,ncycp1d,ncycp2d,ncycp3d,nfile1d,nfile2d,nfile3d,ncycend,ncycshow,sc,ec,remapi;
extern double endtime,t,dt,timep1d,timep2d,timep3d,tprin1d,tprin2d,tprin3d;
extern double svel,cn;
extern double ramb,pamb,tamb,uamb,vamb,wamb,camb,avgmassamb,muamb,tmin,tmax;
extern double dustToGasMassRatio,clumpToInterClumpMassRatio,q0,fML,grainRadius,grainBulkDensity;
extern double remapRadius;
extern double mdot,vinf,esn,msn;
extern double GammaHeat;
#endif
