/*!  \file gridlet.h
 *   \brief This is a repository for the gridlet variables and constants.
 *
 */

using namespace std;

// Constants...
const int nig = 2; // number of gridlets in i-direction
const int njg = 2; // number of gridlets in j-direction
const int nkg = 1; // number of gridlets in k-direction
 
const int ig = lgrid::imax/nig; // number of real cells on the gridlet in the i-direction
const int jg = lgrid::jmax/njg; // number of real cells on the gridlet in the j-direction
const int kg = lgrid::kmax/nkg; // number of real cells on the gridlet in the k-direction

// Total number of zones on the gridlet: [kk][jj][ii]
const int ii = ig + 2*nghost;
#if NDIM > 1
const int jj = jg + 2*nghost;
#else
const int jj = 1;
#endif
#if NDIM == 3
const int kk = kg + 2*nghost;
#else
const int kk = 1;
#endif

// Struct for gridlet
struct gridlet{

  // Variables
  int irs,ire,jrs,jre,krs,kre;
  double p[iqmax][kk][jj][ii]; // primitive variables on gridlet
  double c[iqmax][kk][jj][ii]; // conserved
  double s[iqmax][kk][jj][ii]; // source terms
  double diff[nd][kk][jj][ii][iqmax]; // primitive differences in each direction
  double flux[nd][kk][jj][ii][iqmax]; // conserved fluxes      ---------"-------
  double vol[kk][jj][ii];      // cell volumes on gridlet
  double area[3][kk][jj][ii];  // cell areas in each direction on gridlet
};
  
#ifdef MAIN
gridlet gl;
#else
extern gridlet gl;
#endif

