/*!  \file pdcell.h
 *   \brief This is a repository for temperature dependent mu and gamma arrays.
 *
 *   \param pd (<double>) stores pressure/density.
 *   \param pdmu (<double>) stores mean particle mass (mH units).
 *   \param pdg (<double>) stores gamma.
 *   \param pdh2 (<double>) stores fraction by mass of H2.
 *   \param pdhi (<double>) stores fraction by mass of HI.
 *   \param pdhii (<double>) stores fraction by mass of HII.
 *   \param pdlogt (<double>) stores temperature (K).
 *   \param ied (<double>) stores internal energy/density.
 
 *   \author Julian Pittard (Original version 22.06.11)
 *   \version 0.1-development (Undómiel):
 *   \date Last modified: 04.08.11 (JMP)
 */

// Constants
const int npd = 91;           // Number of p/d entries for molecular phase

// Variables
#ifdef MAIN
double pd[npd];    // lookup table storing pressure/density
double pdmu[npd];  //                      mean particle mass (mH units)
double pdg[npd];   //                      gamma
double pdh2[npd];  //                      fraction by mass of H2
double pdhi[npd];  //                      fraction by mass of HI
double pdhii[npd]; //                      fraction by mass of HII
double pdlogt[npd];//                      temperature (K)
double ied[npd];   //                      internal energy/density
#else
extern double pd[],pdmu[],pdg[],pdh2[],pdhi[],pdhii[],pdlogt[],ied[];
#endif
